@@ -2,21 +2,20 @@ import base64
 import json
 import re
 import time
+
 import pytest
+from behave import given, step, then, when
 
 from algosdk import (
     abi,
+    account,
     atomic_transaction_composer,
     encoding,
     mnemonic,
+    transaction,
 )
 from algosdk.abi.contract import NetworkInfo
-from algosdk.error import (
-    ABITypeError,
-    AtomicTransactionComposerError,
-)
-from algosdk.future import transaction
-from behave import given, step, then, when
+from algosdk.error import ABITypeError, AtomicTransactionComposerError
 from tests.steps.other_v2_steps import read_program
 
 
@@ -426,14 +425,9 @@ def reset_appid_list(context):
 
 @step("I remember the new application ID.")
 def remember_app_id(context):
-    if hasattr(context, "acl"):
-        app_id = context.acl.pending_transaction_info(context.app_txid)[
-            "txresults"
-        ]["createdapp"]
-    else:
-        app_id = context.app_acl.pending_transaction_info(context.app_txid)[
-            "application-index"
-        ]
+    app_id = context.app_acl.pending_transaction_info(context.app_txid)[
+        "application-index"
+    ]
 
     context.current_application_id = app_id
     if not hasattr(context, "app_ids"):
@@ -446,14 +440,7 @@ def remember_app_id(context):
 @step("I wait for the transaction to be confirmed.")
 def wait_for_app_txn_confirm(context):
     wait_for_transaction_processing_to_complete_in_dev_mode()
-    if hasattr(context, "acl"):
-        # TODO: get rid of this branch of logic when v1 fully deprecated
-        assert "type" in context.acl.transaction_info(
-            context.transient_pk, context.app_txid
-        )
-        # assert "type" in context.acl.transaction_by_id(context.app_txid)
-    else:
-        transaction.wait_for_confirmation(context.app_acl, context.app_txid, 1)
+    transaction.wait_for_confirmation(context.app_acl, context.app_txid, 1)
 
 
 @given("an application id {app_id}")
@@ -568,6 +555,17 @@ def create_transaction_with_signer(context):
     )
 
 
+@when(
+    "I create a transaction with an empty signer with the current transaction."
+)
+def create_transaction_no_signer(context):
+    context.transaction_with_signer = (
+        atomic_transaction_composer.TransactionWithSigner(
+            context.transaction, atomic_transaction_composer.EmptySigner()
+        )
+    )
+
+
 @when("I add the current transaction with signer to the composer.")
 def add_transaction_to_composer(context):
     context.atomic_transaction_composer.add_transaction(
@@ -651,7 +649,7 @@ def abi_method_adder(
     if account_type == "transient":
         sender = context.transient_pk
     elif account_type == "signing":
-        sender = mnemonic.to_public_key(context.signing_mnemonic)
+        sender = context.signing_address
     else:
         raise NotImplementedError(
             "cannot make transaction signer for " + account_type
@@ -911,7 +909,7 @@ def check_atomic_transaction_composer_return_type(context, abiTypes):
         assert result.decode_error is None
 
         if expected == "void":
-            assert result.raw_value is None
+            assert result.raw_value == bytes()
             with pytest.raises(ABITypeError):
                 abi.ABIType.from_string(expected)
             continue
