@@ -7,9 +7,23 @@ from pathlib import Path
 from urllib.request import Request, urlopen
 
 import parse
-from algosdk import dryrun_results, encoding, error, mnemonic, source_map
+from behave import register_type  # pylint: disable=no-name-in-module
+from behave import given, step, then, when
+from glom import glom
+
+from algosdk import (
+    dryrun_results,
+    encoding,
+    error,
+    mnemonic,
+    source_map,
+    transaction,
+)
+
+from algosdk.atomic_transaction_composer import (
+    SimulateAtomicTransactionResponse,
+)
 from algosdk.error import AlgodHTTPError
-from algosdk.future import transaction
 from algosdk.testing.dryrun import DryrunTestCaseMixin
 from algosdk.v2client import *
 from algosdk.v2client.models import (
@@ -17,15 +31,8 @@ from algosdk.v2client.models import (
     ApplicationLocalState,
     DryrunRequest,
     DryrunSource,
+    SimulateRequest,
 )
-from behave import (
-    given,
-    register_type,  # pylint: disable=no-name-in-module
-    step,
-    then,
-    when,
-)
-from glom import glom
 from tests.steps.steps import algod_port, indexer_port
 from tests.steps.steps import token as daemon_token
 
@@ -894,8 +901,14 @@ def expect_path(context, path):
         context.response["path"]
     )
     actual_query = urllib.parse.parse_qs(actual_query)
-    assert exp_path == actual_path.replace("%3A", ":")
-    assert exp_query == actual_query
+    actual_path = actual_path.replace("%3A", ":")
+    assert exp_path == actual_path, f"{exp_path} != {actual_path}"
+    assert exp_query == actual_query, f"{exp_query} != {actual_query}"
+
+
+@then('expect the request to be "{method}" "{path}"')
+def expect_request(context, method, path):
+    return expect_path(context, path)
 
 
 @then('expect error string to contain "{err:MaybeString}"')
@@ -1015,7 +1028,7 @@ def compare_to_base64_golden(context, golden):
 @then("the decoded transaction should equal the original")
 def compare_to_original(context):
     encoded = encoding.msgpack_encode(context.signed_transaction)
-    decoded = encoding.future_msgpack_decode(encoded)
+    decoded = encoding.msgpack_decode(encoded)
     assert decoded.transaction == context.transaction
 
 
@@ -1070,6 +1083,17 @@ def b64decode_compiled_teal_step(context, binary):
     assert base64.b64decode(response_result.encode()) == binary
 
 
+@then('disassembly of "{bytecode_filename}" matches "{source_filename}"')
+def disassembly_matches_source(context, bytecode_filename, source_filename):
+    bytecode = load_resource(bytecode_filename)
+    expected_source = load_resource(source_filename).decode("utf-8")
+
+    context.response = context.app_acl.disassemble(bytecode)
+    actual_source = context.response["result"]
+
+    assert actual_source == expected_source
+
+
 @when('I dryrun a "{kind}" program "{program}"')
 def dryrun_step(context, kind, program):
     data = load_resource(program)
@@ -1081,7 +1105,7 @@ def dryrun_step(context, kind, program):
     sources = []
 
     if kind == "compiled":
-        lsig = transaction.LogicSig(data)
+        lsig = transaction.LogicSigAccount(bytes(data))
         txns = [transaction.LogicSigTransaction(txn, lsig)]
     elif kind == "source":
         txns = [transaction.SignedTransaction(txn, None)]
@@ -1360,7 +1384,6 @@ def check_source_map(context, pc_to_line):
 
 @then('getting the line associated with a pc "{pc}" equals "{line}"')
 def check_pc_to_line(context, pc, line):
-
     actual_line = context.source_map.get_line_for_pc(int(pc))
     assert actual_line == int(line), f"expected line {line} got {actual_line}"
 
@@ -1412,3 +1435,115 @@ def transaction_proof(context, round, txid, hashtype):
 @when("we make a Lookup Block Hash call against round {round}")
 def get_block_hash(context, round):
     context.response = context.acl.get_block_hash(round)
+
+
+@when("I simulate the transaction")
+def simulate_transaction(context):
+    context.simulate_response = context.app_acl.simulate_raw_transactions(
+        [context.stx]
+    )
+
+
+@then("the simulation should succeed without any failure message")
+def simulate_transaction_succeed(context):
+    resp = (
+        context.simulate_response
+        if hasattr(context, "simulate_response")
+        else context.atomic_transaction_composer_return.simulate_response
+    )
+
+    for group in resp["txn-groups"]:
+        assert "failure-message" not in group
+
+
+@then("I simulate the current transaction group with the composer")
+def simulate_atc(context):
+    context.atomic_transaction_composer_return = (
+        context.atomic_transaction_composer.simulate(context.app_acl)
+    )
+
+
+@then(
+    'the simulation should report a failure at group "{group}", path "{path}" with message "{message}"'
+)
+def simulate_atc_failure(context, group, path, message):
+    if hasattr(context, "simulate_response"):
+        resp = context.simulate_response
+    else:
+        resp = context.atomic_transaction_composer_return.simulate_response
+    group_idx: int = int(group)
+    fail_path = ",".join(
+        [str(pe) for pe in resp["txn-groups"][group_idx]["failed-at"]]
+    )
+    assert fail_path == path
+    assert message in resp["txn-groups"][group_idx]["failure-message"]
+
+
+@when("I make a new simulate request.")
+def make_simulate_request(context):
+    context.simulate_request = SimulateRequest(txn_groups=[])
+
+
+@then("I allow more logs on that simulate request.")
+def allow_more_logs_in_request(context):
+    context.simulate_request.allow_more_logs = True
+
+
+@then("I simulate the transaction group with the simulate request.")
+def simulate_group_with_request(context):
+    context.atomic_transaction_composer_return = (
+        context.atomic_transaction_composer.simulate(
+            context.app_acl, context.simulate_request
+        )
+    )
+
+
+@then("I check the simulation result has power packs allow-more-logging.")
+def power_pack_simulation_should_pass(context):
+    assert context.atomic_transaction_composer_return.eval_overrides
+    assert (
+        context.atomic_transaction_composer_return.eval_overrides.max_log_calls
+    )
+    assert (
+        context.atomic_transaction_composer_return.eval_overrides.max_log_size
+    )
+
+
+@when("I prepare the transaction without signatures for simulation")
+def step_impl(context):
+    context.stx = transaction.SignedTransaction(context.txn, None)
+
+
+@when("we make a GetLedgerStateDelta call against round {round}")
+def get_ledger_state_delta_call(context, round):
+    context.response = context.acl.get_ledger_state_delta(round)
+
+
+@when("we make a SetSyncRound call against round {round}")
+def set_sync_round_call(context, round):
+    context.response = context.acl.set_sync_round(round)
+
+
+@when("we make a GetSyncRound call")
+def get_sync_round_call(context):
+    context.response = context.acl.get_sync_round()
+
+
+@when("we make a UnsetSyncRound call")
+def unset_sync_round_call(context):
+    context.response = context.acl.unset_sync_round()
+
+
+@when("we make a Ready call")
+def ready_call(context):
+    context.response = context.acl.ready()
+
+
+@when("we make a SetBlockTimeStampOffset call against offset {offset}")
+def set_block_timestamp_offset(context, offset):
+    context.response = context.acl.set_timestamp_offset(offset)
+
+
+@when("we make a GetBlockTimeStampOffset call")
+def get_block_timestamp_offset(context):
+    context.response = context.acl.get_timestamp_offset()
